function A = Hermite_2(alappontok, ertekek)
%Hermite interpolci; ha egy alappont tbbszr szerepel, akkor az
%ertekek vektorban a megfelel indexeken f(x_i), f'(x_i),... szerepel.

n = length(alappontok);

A = NaN*ones(n,n+1);

A(:,1) = alappontok;
A(:,2) = ertekek;

for i=1:n-1,
    if A(i,1) == A(i+1,1),
        A(i+1,2) = A(i,2);
    end;
end;

k = 1;
while k<n,
    p = k+1;
    while p<=n && A(k,1) == A(p,1),
        for q = p-k+2:-1:3,
            A(p,q) = ertekek(q+k-2) / factorial(q-2);
        end;
        p = p + 1;
    end;
    k = p;
end;

for i=3:(n+1),  %cellk feltltse
    for j=(i-1):n,
        if A(j,i) ~= A(j,i), %mg nincs kitltve (NaN)
            A(j,i) = (A(j,i-1)-A(j-1,i-1)) / (A(j,1)-A(j-i+2,1));
        end;
    end;
end;

x = [min(alappontok):0.001:max(alappontok)];
omega_n = ones(size(x));
y = zeros(size(x));

for i=1:n,
    y = y + (A(i,i+1) * omega_n);
    omega_n = omega_n .* (x-alappontok(i));
end;

plot(x,y,A(:,1),A(:,2),'ro');